==> iCellR_1.6.5.tar.gz: iCellR/R/F0100.R <==
utils::globalVariables(c("%>%",
                         "..p.format..",
                         "xend",
                         "x",
                         "y",
                         "AlignSubspace",
                         "CaseMatch",
                         "CreateSeuratObject",
                         "FindVariableGenes",
                         "Freq",
                         "Mito.UMIs",
                         "MyLev",
                         "NormalizeData",
                         "PCs",
                         "RunCCA",
                         "S.phase.probability",
                         "SDs",
                         "ScaleData",
                         "SetAllIdent",
                         "StashIdent",
                         "UMIs",
                         "Var1",
                         "baseMean",
                         "cdr3",
                         "cell",
                         "cells",
                         "chain",
                         "clusters",
                         "color",
                         "conditions",
                         "distance",
                         "event_data",
                         "g2m.phase",
                         "g2m.phase.probability",
                         "gene",
                         "gene.filter",
                         "genes",
                         "immgen.rna",
                         "immgen.uli.rna",
                         "demo.obj",
                         "my.vdj",
                         "lfc",
                         "log2FoldChange",
                         "magic",
                         "mito.percent",
                         "mouse.cell.atlas",
                         "my.vdj.chain",
                         "nGenes",
                         "numberOfCells",
                         "padj",
                         "phate",
                         "plotlyOutput",
                         "productive",
                         "pval",
                         "pvalue",
                         "raw_clonotype_id",
                         "renderPlotly",
                         "s.phase",
                         "scale_size",
                         "unit",
                         "cell.barcodes",
                         "Expression",
                         "Conditions",
                         "col.legend.bin",
                         "Clusters",
                         "Rphenograph",
                         "membership",
                         "SerialParam",
                         "SingleCellExperiment",
                         "computeSumFactors",
                         "normalize",
                         "out",
                         "DefaultAssay<-",
                         "IntegrateData",
                         "FindIntegrationAnchors",
                         "FindVariableFeatures",
                         "DiffusionMap",
                         "SCTransform",
                         "Norm.Freq",
                         "SelectIntegrationFeatures",
                         "PrepSCTIntegration",
                         "Phase",
                         "percentage",
                         "Immgen.microarray.GSE37448.189",
                         "Immgen.microarray.GSE15907.653",
                         "Immgen.GSE124829.190",
                         "Immgen.GSE122597.83",
                         "Immgen.GSE122108.412",
                         "Immgen.GSE109125.205",
                         "yend",
                         "gg_color_hue",
                         "hcl",
                         "V",
                         "CellIds",
                         "V<-",
                         "AddModuleScoreme",
                         "genes.list",
                         "annotate",
                         "wilcox.test",
                         "gsva",
                         "V5",
                         "V6",
                         "AvExpInOtherClusters",
                         "X1",
                         "X2",
                         "X3"))
#########
# F001.load10x.R | F001.R
# F002.data.aggregation.R | F002.R
# F003.make.obj.R | F003.R
# F044.myclass.R | F0044.R
# F004.qc.stats.R | F004.R
# F005.stats.plot.R | F005.R
# F006.cell.filter.R | F006.R
# F007.down.sample.R | F007.R
# F008.norm.data.R | F008.R
# F009.data.scale.R | F009.R
# F010.gene.stats.R | F0010.R
# F011.make.gene.model.R | F0011.R
# F012.run.pca.R | F0012.R
# F013.opt.pcs.plot.R | F0013.R
# F014.find.dim.genes.R | F0014.R
# F015.run.clustering.R | F0015.R
# F016.clust.cond.info.R | F0016.R
# F017.run.pc.tsne.R | F0017.R
# F018.run.umap.R | F0018.R
# F019.run.diffusion.map.R | F0019.R
# F020.cluster.plot.R | F0020.R
# F021.clust.avg.exp.R | F0021.R
# F022.run.imput.R | F0022.R
# F023.cell.gating.R | F0023.R
# F024.gate.to.clust.R | F0024.R
# F025.change.clust.R | F0025.R
# F026.clust.rm.R | F0026.R
# F027.clust.stats.plot.R | F0027.R
# F028.findMarkers.R | F0028.R
# F029.top.markers.R | F0029.R
# F030.heatmap.gg.plot.R | F0030.R
# F031.gene.plot.R | F0031.R
# F032.pseudotime.tree.R | F0032.R
# F033.cell.type.pred.R | F0033.R
# F034.diff.exp.R | F0034.R
# F035.volcano.ma.plot.R | F0035.R
# F036.add.adt.R | F0036.R
# F037.norm.adt.R | F0037.R
# F038.adt.rna.merge.R | F0038.R
# F039.prep.vdj.R | F0039.R
# F040.add.vdj.R | F0040.R
# F041.clono.plot.R | F0041.R
# F042vdj.stats.R | F0042.R
# F043.run.tsne.R | F0043.R
# F045.cc.R | F0045.R
# RcppExports.R | F0046.R
# Rphenograph.R | F0047.R
# abstract.graph.R | F0048.R
# cell.cycle.R | F0049.R
# clust.ord.R | F0050.R
# data.Sphase.R | F0051.R
# make.bed.R | F0052.R (Used to be data.demo.obj.R | F0052.R)
# data.g2m.R | F0053.R
# findKNN.R | F0054.R
# gg.cor.R | F0055.R
# globalVariables.R | F0056.R
# hto.anno.R | F0057.R
# run.knetl.R | F0058.R
# iba.R | F0059.R
# iclust.R | F0060.R
# k.myImp.R | F0061.R
# k.pseudotime.R | F0062.R
# k.run.cca.R | F0063.R
# load.h5.R | F0064.R
# run.anchor.R | F0065.R
# run.mnn.R | F0066.R
# run.phenograph.r | F0067.R
# image.capture.10x.R | F0068.R
# add.10x.image.R | F0069.R
# spatial.plot.R | F0070.R
# i.score.R | F0071.R

==> iCellR_1.6.7.tar.gz: iCellR/R/F0100.R <==
utils::globalVariables(c("%>%",
                         "..p.format..",
                         "xend",
                         "x",
                         "y",
                         "AlignSubspace",
                         "CaseMatch",
                         "CreateSeuratObject",
                         "FindVariableGenes",
                         "Freq",
                         "Mito.UMIs",
                         "MyLev",
                         "NormalizeData",
                         "PCs",
                         "RunCCA",
                         "S.phase.probability",
                         "SDs",
                         "ScaleData",
                         "SetAllIdent",
                         "StashIdent",
                         "UMIs",
                         "Var1",
                         "baseMean",
                         "cdr3",
                         "cell",
                         "cells",
                         "chain",
                         "clusters",
                         "cluster",
                         "color",
                         "conditions",
                         "distance",
                         "event_data",
                         "g2m.phase",
                         "g2m.phase.probability",
                         "gene",
                         "gene.filter",
                         "genes",
                         "immgen.rna",
                         "immgen.uli.rna",
                         "demo.obj",
                         "my.vdj",
                         "lfc",
                         "log2FoldChange",
                         "magic",
                         "mito.percent",
                         "mouse.cell.atlas",
                         "my.vdj.chain",
                         "nGenes",
                         "numberOfCells",
                         "padj",
                         "phate",
                         "plotlyOutput",
                         "productive",
                         "pval",
                         "pvalue",
                         "raw_clonotype_id",
                         "renderPlotly",
                         "s.phase",
                         "scale_size",
                         "unit",
                         "cell.barcodes",
                         "Expression",
                         "Conditions",
                         "col.legend.bin",
                         "Clusters",
                         "Rphenograph",
                         "membership",
                         "SerialParam",
                         "SingleCellExperiment",
                         "computeSumFactors",
                         "normalize",
                         "out",
                         "DefaultAssay<-",
                         "IntegrateData",
                         "FindIntegrationAnchors",
                         "FindVariableFeatures",
                         "DiffusionMap",
                         "SCTransform",
                         "Norm.Freq",
                         "SelectIntegrationFeatures",
                         "PrepSCTIntegration",
                         "Phase",
                         "percentage",
                         "Immgen.microarray.GSE37448.189",
                         "Immgen.microarray.GSE15907.653",
                         "Immgen.GSE124829.190",
                         "Immgen.GSE122597.83",
                         "Immgen.GSE122108.412",
                         "Immgen.GSE109125.205",
                         "yend",
                         "gg_color_hue",
                         "hcl",
                         "V",
                         "CellIds",
                         "V<-",
                         "AddModuleScoreme",
                         "genes.list",
                         "annotate",
                         "wilcox.test",
                         "gsva",
                         "V5",
                         "V6",
                         "AvExpInOtherClusters",
                         "X1",
                         "X2",
                         "X3"))
#########
# F001.load10x.R | F001.R
# F002.data.aggregation.R | F002.R
# F003.make.obj.R | F003.R
# F044.myclass.R | F0044.R
# F004.qc.stats.R | F004.R
# F005.stats.plot.R | F005.R
# F006.cell.filter.R | F006.R
# F007.down.sample.R | F007.R
# F008.norm.data.R | F008.R
# F009.data.scale.R | F009.R
# F010.gene.stats.R | F0010.R
# F011.make.gene.model.R | F0011.R
# F012.run.pca.R | F0012.R
# F013.opt.pcs.plot.R | F0013.R
# F014.find.dim.genes.R | F0014.R
# F015.run.clustering.R | F0015.R
# F016.clust.cond.info.R | F0016.R
# F017.run.pc.tsne.R | F0017.R
# F018.run.umap.R | F0018.R
# F019.run.diffusion.map.R | F0019.R
# F020.cluster.plot.R | F0020.R
# F021.clust.avg.exp.R | F0021.R
# F022.run.imput.R | F0022.R
# F023.cell.gating.R | F0023.R
# F024.gate.to.clust.R | F0024.R
# F025.change.clust.R | F0025.R
# F026.clust.rm.R | F0026.R
# F027.clust.stats.plot.R | F0027.R
# F028.findMarkers.R | F0028.R
# F029.top.markers.R | F0029.R
# F030.heatmap.gg.plot.R | F0030.R
# F031.gene.plot.R | F0031.R
# F032.pseudotime.tree.R | F0032.R
# F033.cell.type.pred.R | F0033.R
# F034.diff.exp.R | F0034.R
# F035.volcano.ma.plot.R | F0035.R
# F036.add.adt.R | F0036.R
# F037.norm.adt.R | F0037.R
# F038.adt.rna.merge.R | F0038.R
# F039.prep.vdj.R | F0039.R
# F040.add.vdj.R | F0040.R
# F041.clono.plot.R | F0041.R
# F042vdj.stats.R | F0042.R
# F043.run.tsne.R | F0043.R
# F045.cc.R | F0045.R
# RcppExports.R | F0046.R
# Rphenograph.R | F0047.R
# abstract.graph.R | F0048.R
# cell.cycle.R | F0049.R
# clust.ord.R | F0050.R
# data.Sphase.R | F0051.R
# make.bed.R | F0052.R (Used to be data.demo.obj.R | F0052.R)
# data.g2m.R | F0053.R
# findKNN.R | F0054.R
# gg.cor.R | F0055.R
# globalVariables.R | F0056.R
# hto.anno.R | F0057.R
# run.knetl.R | F0058.R
# iba.R | F0059.R
# iclust.R | F0060.R
# k.myImp.R | F0061.R
# k.pseudotime.R | F0062.R
# k.run.cca.R | F0063.R
# load.h5.R | F0064.R
# run.anchor.R | F0065.R
# run.mnn.R | F0066.R
# run.phenograph.r | F0067.R
# image.capture.10x.R | F0068.R
# add.10x.image.R | F0069.R
# spatial.plot.R | F0070.R
# i.score.R | F0071.R
# bubble.gg.plot.R | F0072.R
# ############### F0100.R ################# and F0044.R ######################
